@@ -8,15 +8,17 @@ logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
                     level=logging.DEBUG,
                     stream=sys.stdout)
 import yaml
+import json
 # mine
 import hwrt.utils as utils
 
 
 def main(model_folder):
-    recording = yaml.load(sys.stdin.readline())
+    recording = sys.stdin.readline()
+    raw_data_json = json.dumps(yaml.load(recording))
     logging.info(recording)
     logging.info("Start evaluation...")
-    print(utils.evaluate_model(recording, model_folder))
+    print(utils.evaluate_model(raw_data_json, model_folder))
 
 
 def get_parser():
