@@ -357,13 +357,13 @@ def evaluate_model(recording, model_folder):
         # The source is later than the target. That means we need to
         # refresh the target
         if "preprocessed" in target_folder:
-            logging.info("Start applying preprocessing methods")
+            logging.info("Start applying preprocessing methods...")
             t = target_folder
             _, _, preprocessing_queue = preprocess_dataset.get_parameters(t)
             handwriting = HandwrittenData(recording)
             handwriting.preprocessing(preprocessing_queue)
         elif "feature-files" in target_folder:
-            logging.info("Feature file was outdated. Update...")
+            logging.info("Create feature file...")
             infofile_path = os.path.join(target_folder, "info.yml")
             with open(infofile_path, 'r') as ymlfile:
                 feature_description = yaml.load(ymlfile)
@@ -376,7 +376,7 @@ def evaluate_model(recording, model_folder):
             input_filename = "tmp.txt"
             output_filename = "evaluate.pfile"
             with open(input_filename, "w") as f:
-                for symbolnr, instance in enumerate([(x, "0")]):
+                for symbolnr, instance in enumerate([(x, 0)]):
                     feature_string, label = instance
                     assert len(feature_string) == feature_count, \
                         "Expected %i features, got %i features" % \
@@ -389,6 +389,7 @@ def evaluate_model(recording, model_folder):
             logging.info(command)
             os.system(command)
         elif "model" in target_folder:
+            logging.info("Create running model...")
             model_src = get_latest_model(target_folder, "model")
             model_use = "tmp.json"
             create_adjusted_model_for_percentages(model_src, model_use)
